diff --git a/.gradle/9.4.1/executionHistory/executionHistory.bin b/.gradle/9.4.1/executionHistory/executionHistory.bin
index 3793da1..896f4cc 100644
Binary files a/.gradle/9.4.1/executionHistory/executionHistory.bin and b/.gradle/9.4.1/executionHistory/executionHistory.bin differ
diff --git a/.gradle/9.4.1/executionHistory/executionHistory.lock b/.gradle/9.4.1/executionHistory/executionHistory.lock
index 74bed02..8602ff7 100644
Binary files a/.gradle/9.4.1/executionHistory/executionHistory.lock and b/.gradle/9.4.1/executionHistory/executionHistory.lock differ
diff --git a/.gradle/9.4.1/fileHashes/fileHashes.bin b/.gradle/9.4.1/fileHashes/fileHashes.bin
index 6cec97c..76dba2a 100644
Binary files a/.gradle/9.4.1/fileHashes/fileHashes.bin and b/.gradle/9.4.1/fileHashes/fileHashes.bin differ
diff --git a/.gradle/9.4.1/fileHashes/fileHashes.lock b/.gradle/9.4.1/fileHashes/fileHashes.lock
index c5f3e94..1f79697 100644
Binary files a/.gradle/9.4.1/fileHashes/fileHashes.lock and b/.gradle/9.4.1/fileHashes/fileHashes.lock differ
diff --git a/.gradle/9.4.1/fileHashes/resourceHashesCache.bin b/.gradle/9.4.1/fileHashes/resourceHashesCache.bin
index 2d7c82d..2ea106a 100644
Binary files a/.gradle/9.4.1/fileHashes/resourceHashesCache.bin and b/.gradle/9.4.1/fileHashes/resourceHashesCache.bin differ
diff --git a/.gradle/buildOutputCleanup/buildOutputCleanup.lock b/.gradle/buildOutputCleanup/buildOutputCleanup.lock
index aa3cb55..6a244ef 100644
Binary files a/.gradle/buildOutputCleanup/buildOutputCleanup.lock and b/.gradle/buildOutputCleanup/buildOutputCleanup.lock differ
diff --git a/.gradle/buildOutputCleanup/outputFiles.bin b/.gradle/buildOutputCleanup/outputFiles.bin
index af42711..0e4b270 100644
Binary files a/.gradle/buildOutputCleanup/outputFiles.bin and b/.gradle/buildOutputCleanup/outputFiles.bin differ
diff --git a/.gradle/file-system.probe b/.gradle/file-system.probe
index aae018a..a90df38 100644
Binary files a/.gradle/file-system.probe and b/.gradle/file-system.probe differ
diff --git a/.idea/caches/deviceStreaming.xml b/.idea/caches/deviceStreaming.xml
index 05c51b5..dbc65bb 100644
--- a/.idea/caches/deviceStreaming.xml
+++ b/.idea/caches/deviceStreaming.xml
@@ -580,6 +580,30 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -760,6 +784,18 @@
+
+
+
+
+
+
+
+
+
+
+
+
@@ -1278,6 +1314,18 @@
+
+
+
+
+
+
+
+
+
+
+
+
@@ -1664,6 +1712,18 @@
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/.idea/deploymentTargetSelector.xml b/.idea/deploymentTargetSelector.xml
index e2e9289..b3b881a 100644
--- a/.idea/deploymentTargetSelector.xml
+++ b/.idea/deploymentTargetSelector.xml
@@ -4,10 +4,10 @@
-
+
-
+
diff --git a/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityDetalhePacienteBinding.java b/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityDetalhePacienteBinding.java
index e1d57df..1a39b64 100644
--- a/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityDetalhePacienteBinding.java
+++ b/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityDetalhePacienteBinding.java
@@ -12,6 +12,7 @@ import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.viewbinding.ViewBinding;
import androidx.viewbinding.ViewBindings;
import com.example.medcuida.pro.R;
+import com.google.android.material.button.MaterialButton;
import java.lang.NullPointerException;
import java.lang.Override;
import java.lang.String;
@@ -20,6 +21,12 @@ public final class ActivityDetalhePacienteBinding implements ViewBinding {
@NonNull
private final ConstraintLayout rootView;
+ @NonNull
+ public final MaterialButton btnAdicionarMedicamento;
+
+ @NonNull
+ public final MaterialButton btnAgendarConsulta;
+
@NonNull
public final ImageButton btnSairDetalhe;
@@ -42,11 +49,14 @@ public final class ActivityDetalhePacienteBinding implements ViewBinding {
public final TextView tvSexoPaciente;
private ActivityDetalhePacienteBinding(@NonNull ConstraintLayout rootView,
+ @NonNull MaterialButton btnAdicionarMedicamento, @NonNull MaterialButton btnAgendarConsulta,
@NonNull ImageButton btnSairDetalhe, @NonNull TextView tvEmailPaciente,
@NonNull TextView tvIdadePaciente, @NonNull TextView tvMedicacaoPaciente,
@NonNull TextView tvNomePaciente, @NonNull TextView tvNumeroUtente,
@NonNull TextView tvSexoPaciente) {
this.rootView = rootView;
+ this.btnAdicionarMedicamento = btnAdicionarMedicamento;
+ this.btnAgendarConsulta = btnAgendarConsulta;
this.btnSairDetalhe = btnSairDetalhe;
this.tvEmailPaciente = tvEmailPaciente;
this.tvIdadePaciente = tvIdadePaciente;
@@ -83,6 +93,18 @@ public final class ActivityDetalhePacienteBinding implements ViewBinding {
// This is done to optimize the compiled bytecode for size and performance.
int id;
missingId: {
+ id = R.id.btn_adicionar_medicamento;
+ MaterialButton btnAdicionarMedicamento = ViewBindings.findChildViewById(rootView, id);
+ if (btnAdicionarMedicamento == null) {
+ break missingId;
+ }
+
+ id = R.id.btn_agendar_consulta;
+ MaterialButton btnAgendarConsulta = ViewBindings.findChildViewById(rootView, id);
+ if (btnAgendarConsulta == null) {
+ break missingId;
+ }
+
id = R.id.btn_sair_detalhe;
ImageButton btnSairDetalhe = ViewBindings.findChildViewById(rootView, id);
if (btnSairDetalhe == null) {
@@ -125,9 +147,9 @@ public final class ActivityDetalhePacienteBinding implements ViewBinding {
break missingId;
}
- return new ActivityDetalhePacienteBinding((ConstraintLayout) rootView, btnSairDetalhe,
- tvEmailPaciente, tvIdadePaciente, tvMedicacaoPaciente, tvNomePaciente, tvNumeroUtente,
- tvSexoPaciente);
+ return new ActivityDetalhePacienteBinding((ConstraintLayout) rootView,
+ btnAdicionarMedicamento, btnAgendarConsulta, btnSairDetalhe, tvEmailPaciente,
+ tvIdadePaciente, tvMedicacaoPaciente, tvNomePaciente, tvNumeroUtente, tvSexoPaciente);
}
String missingId = rootView.getResources().getResourceName(id);
throw new NullPointerException("Missing required view with ID: ".concat(missingId));
diff --git a/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityMainBinding.java b/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityMainBinding.java
index 0a39b6e..13efbae 100644
--- a/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityMainBinding.java
+++ b/app/build/generated/data_binding_base_class_source_out/debug/out/com/example/medcuida/pro/databinding/ActivityMainBinding.java
@@ -18,6 +18,7 @@ import androidx.viewbinding.ViewBindings;
import com.example.medcuida.pro.R;
import com.google.android.material.bottomnavigation.BottomNavigationView;
import com.google.android.material.button.MaterialButton;
+import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.google.android.material.imageview.ShapeableImageView;
import com.google.android.material.textfield.TextInputEditText;
import com.google.android.material.textfield.TextInputLayout;
@@ -59,6 +60,9 @@ public final class ActivityMainBinding implements ViewBinding {
@NonNull
public final TextInputEditText editSearchPacientes;
+ @NonNull
+ public final FloatingActionButton fabAddConsulta;
+
@NonNull
public final ShapeableImageView imgPerfilMain;
@@ -128,17 +132,17 @@ public final class ActivityMainBinding implements ViewBinding {
@NonNull ImageButton btnNextDayHist, @NonNull ImageButton btnPrevDayHist,
@NonNull LinearLayout btnSelectDateHist, @NonNull CalendarView calendarView,
@NonNull FrameLayout container, @NonNull TextInputEditText editSearchPacientes,
- @NonNull ShapeableImageView imgPerfilMain, @NonNull LinearLayout layTop,
- @NonNull RecyclerView recyclerAceites, @NonNull RecyclerView recyclerAgenda,
- @NonNull RecyclerView recyclerConsultas, @NonNull TextInputLayout searchLayoutPacientes,
- @NonNull TextView textAceitesEmpty, @NonNull TextView textAgendaInfoHist,
- @NonNull TextView textAgendaVazia, @NonNull TextView textEmptyState,
- @NonNull TextView textSelectedDateFullHist, @NonNull TextView tvCedula,
- @NonNull TextView tvEmailMedico, @NonNull TextView tvEspecialidade,
- @NonNull TextView tvGreetingMain, @NonNull TextView tvHorarioPerfil,
- @NonNull TextView tvNomeMedico, @NonNull LinearLayout viewAceites,
- @NonNull LinearLayout viewAgenda, @NonNull LinearLayout viewPacientes,
- @NonNull LinearLayout viewPerfil) {
+ @NonNull FloatingActionButton fabAddConsulta, @NonNull ShapeableImageView imgPerfilMain,
+ @NonNull LinearLayout layTop, @NonNull RecyclerView recyclerAceites,
+ @NonNull RecyclerView recyclerAgenda, @NonNull RecyclerView recyclerConsultas,
+ @NonNull TextInputLayout searchLayoutPacientes, @NonNull TextView textAceitesEmpty,
+ @NonNull TextView textAgendaInfoHist, @NonNull TextView textAgendaVazia,
+ @NonNull TextView textEmptyState, @NonNull TextView textSelectedDateFullHist,
+ @NonNull TextView tvCedula, @NonNull TextView tvEmailMedico,
+ @NonNull TextView tvEspecialidade, @NonNull TextView tvGreetingMain,
+ @NonNull TextView tvHorarioPerfil, @NonNull TextView tvNomeMedico,
+ @NonNull LinearLayout viewAceites, @NonNull LinearLayout viewAgenda,
+ @NonNull LinearLayout viewPacientes, @NonNull LinearLayout viewPerfil) {
this.rootView = rootView;
this.bottomNavigation = bottomNavigation;
this.btnEditarDados = btnEditarDados;
@@ -150,6 +154,7 @@ public final class ActivityMainBinding implements ViewBinding {
this.calendarView = calendarView;
this.container = container;
this.editSearchPacientes = editSearchPacientes;
+ this.fabAddConsulta = fabAddConsulta;
this.imgPerfilMain = imgPerfilMain;
this.layTop = layTop;
this.recyclerAceites = recyclerAceites;
@@ -260,6 +265,12 @@ public final class ActivityMainBinding implements ViewBinding {
break missingId;
}
+ id = R.id.fab_add_consulta;
+ FloatingActionButton fabAddConsulta = ViewBindings.findChildViewById(rootView, id);
+ if (fabAddConsulta == null) {
+ break missingId;
+ }
+
id = R.id.img_perfil_main;
ShapeableImageView imgPerfilMain = ViewBindings.findChildViewById(rootView, id);
if (imgPerfilMain == null) {
@@ -388,11 +399,11 @@ public final class ActivityMainBinding implements ViewBinding {
return new ActivityMainBinding((RelativeLayout) rootView, bottomNavigation, btnEditarDados,
btnGoTodayIconHist, btnLogout, btnNextDayHist, btnPrevDayHist, btnSelectDateHist,
- calendarView, container, editSearchPacientes, imgPerfilMain, layTop, recyclerAceites,
- recyclerAgenda, recyclerConsultas, searchLayoutPacientes, textAceitesEmpty,
- textAgendaInfoHist, textAgendaVazia, textEmptyState, textSelectedDateFullHist, tvCedula,
- tvEmailMedico, tvEspecialidade, tvGreetingMain, tvHorarioPerfil, tvNomeMedico,
- viewAceites, viewAgenda, viewPacientes, viewPerfil);
+ calendarView, container, editSearchPacientes, fabAddConsulta, imgPerfilMain, layTop,
+ recyclerAceites, recyclerAgenda, recyclerConsultas, searchLayoutPacientes,
+ textAceitesEmpty, textAgendaInfoHist, textAgendaVazia, textEmptyState,
+ textSelectedDateFullHist, tvCedula, tvEmailMedico, tvEspecialidade, tvGreetingMain,
+ tvHorarioPerfil, tvNomeMedico, viewAceites, viewAgenda, viewPacientes, viewPerfil);
}
String missingId = rootView.getResources().getResourceName(id);
throw new NullPointerException("Missing required view with ID: ".concat(missingId));
diff --git a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-dependencies.xml b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-dependencies.xml
index e67464c..52f547e 100644
--- a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-dependencies.xml
+++ b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-dependencies.xml
@@ -1,6 +1,6 @@
+ roots=":@@:app::debug,androidx.test.ext:junit:1.1.5@aar,androidx.test.espresso:espresso-core:3.5.1@aar,androidx.databinding:viewbinding:9.2.0@aar,androidx.navigation:navigation-common:2.7.7@aar,androidx.navigation:navigation-runtime:2.7.7@aar,androidx.navigation:navigation-fragment:2.7.7@aar,androidx.navigation:navigation-ui:2.7.7@aar,com.google.android.material:material:1.11.0@aar,androidx.appcompat:appcompat:1.6.1@aar,androidx.constraintlayout:constraintlayout:2.1.4@aar,androidx.appcompat:appcompat-resources:1.6.1@aar,com.github.bumptech.glide:glide:4.16.0@aar,androidx.viewpager2:viewpager2:1.0.0@aar,androidx.fragment:fragment-ktx:1.6.2@aar,androidx.credentials:credentials-play-services-auth:1.5.0@aar,com.google.android.libraries.identity.googleid:googleid:1.1.1@aar,androidx.credentials:credentials:1.5.0@aar,androidx.credentials:credentials:1.5.0@aar,androidx.biometric:biometric:1.1.0@aar,com.google.android.gms:play-services-location:21.0.1@aar,com.google.firebase:firebase-firestore:24.10.2@aar,com.google.firebase:firebase-storage:20.3.0@aar,com.google.firebase:firebase-auth:22.3.1@aar,com.google.android.gms:play-services-auth-api-phone:17.4.0@aar,com.google.firebase:firebase-database-collection:18.0.1@aar,com.google.firebase:firebase-appcheck:17.1.2@aar,com.google.firebase:firebase-appcheck-interop:17.1.0@aar,com.google.android.gms:play-services-base:18.1.0@aar,com.google.android.recaptcha:recaptcha:18.4.0@aar,com.google.android.play:integrity:1.2.0@aar,com.google.firebase:firebase-auth-interop:20.0.0@aar,com.google.firebase:firebase-common-ktx:20.4.2@aar,com.google.firebase:firebase-common:20.4.2@aar,androidx.test:core:1.5.0@aar,androidx.dynamicanimation:dynamicanimation:1.0.0@aar,androidx.legacy:legacy-support-core-utils:1.0.0@aar,androidx.loader:loader:1.0.0@aar,androidx.activity:activity-ktx:1.8.0@aar,androidx.lifecycle:lifecycle-runtime-ktx:2.7.0@aar,androidx.lifecycle:lifecycle-viewmodel-savedstate:2.7.0@aar,androidx.lifecycle:lifecycle-livedata-core:2.7.0@aar,androidx.lifecycle:lifecycle-viewmodel:2.7.0@aar,androidx.lifecycle:lifecycle-viewmodel:2.7.0@aar,androidx.lifecycle:lifecycle-livedata-core-ktx:2.7.0@aar,androidx.lifecycle:lifecycle-livedata:2.7.0@aar,androidx.lifecycle:lifecycle-livedata:2.7.0@aar,androidx.lifecycle:lifecycle-common:2.7.0@jar,org.jetbrains.kotlinx:kotlinx-coroutines-android:1.7.3@jar,org.jetbrains.kotlinx:kotlinx-coroutines-core-jvm:1.7.3@jar,org.jetbrains.kotlinx:kotlinx-coroutines-play-services:1.7.3@jar,com.google.android.gms:play-services-tasks:18.1.0@aar,com.google.android.gms:play-services-basement:18.3.0@aar,androidx.fragment:fragment:1.6.2@aar,androidx.fragment:fragment:1.6.2@aar,androidx.activity:activity:1.8.0@aar,androidx.drawerlayout:drawerlayout:1.1.1@aar,androidx.coordinatorlayout:coordinatorlayout:1.1.0@aar,androidx.transition:transition:1.2.0@aar,androidx.vectordrawable:vectordrawable-animated:1.1.0@aar,androidx.vectordrawable:vectordrawable:1.1.0@aar,androidx.slidingpanelayout:slidingpanelayout:1.2.0@aar,androidx.recyclerview:recyclerview:1.1.0@aar,androidx.viewpager:viewpager:1.0.0@aar,androidx.customview:customview:1.1.0@aar,androidx.browser:browser:1.4.0@aar,androidx.core:core-ktx:1.9.0@aar,androidx.core:core:1.9.0@aar,androidx.core:core:1.9.0@aar,androidx.lifecycle:lifecycle-runtime:2.7.0@aar,androidx.lifecycle:lifecycle-viewmodel-ktx:2.7.0@aar,androidx.lifecycle:lifecycle-livedata-ktx:2.7.0@aar,com.google.ai.client.generativeai:generativeai:0.9.0@aar,io.grpc:grpc-stub:1.57.2@jar,com.google.guava:guava:32.0.1-android@jar,com.squareup.retrofit2:converter-gson:2.9.0@jar,com.squareup.retrofit2:retrofit:2.9.0@jar,com.squareup.okhttp3:okhttp:4.10.0@jar,androidx.test:runner:1.5.2@aar,junit:junit:4.13.2@jar,org.hamcrest:hamcrest-integration:1.3@jar,org.hamcrest:hamcrest-library:1.3@jar,org.hamcrest:hamcrest-core:1.3@jar,androidx.test.services:storage:1.4.2@aar,androidx.test:monitor:1.6.1@aar,androidx.test:annotation:1.0.1@aar,androidx.cursoradapter:cursoradapter:1.0.0@aar,androidx.cardview:cardview:1.0.0@aar,com.github.bumptech.glide:gifdecoder:4.16.0@aar,androidx.concurrent:concurrent-futures:1.2.0-alpha03@jar,androidx.versionedparcelable:versionedparcelable:1.1.1@aar,androidx.collection:collection-ktx:1.1.0@jar,androidx.collection:collection:1.1.0@jar,androidx.savedstate:savedstate-ktx:1.2.1@aar,androidx.savedstate:savedstate:1.2.1@aar,androidx.arch.core:core-runtime:2.2.0@aar,androidx.arch.core:core-common:2.2.0@jar,androidx.localbroadcastmanager:localbroadcastmanager:1.0.0@aar,com.google.firebase:firebase-components:17.1.5@aar,androidx.interpolator:interpolator:1.0.0@aar,androidx.documentfile:documentfile:1.0.0@aar,androidx.print:print:1.0.0@aar,androidx.annotation:annotation-jvm:1.8.1@jar,androidx.annotation:annotation-experimental:1.4.1@aar,com.squareup.okio:okio-jvm:3.0.0@jar,org.jetbrains.kotlin:kotlin-stdlib-jdk8:1.8.22@jar,org.jetbrains.kotlin:kotlin-stdlib-jdk7:1.8.22@jar,org.jetbrains.kotlin:kotlin-stdlib:2.2.10@jar,org.jetbrains:annotations:23.0.0@jar,androidx.tracing:tracing:1.2.0@aar,io.grpc:grpc-protobuf-lite:1.57.2@jar,io.grpc:grpc-android:1.57.2@aar,io.grpc:grpc-okhttp:1.57.2@jar,io.grpc:grpc-core:1.57.2@jar,io.grpc:grpc-api:1.57.2@jar,com.google.code.findbugs:jsr305:3.0.2@jar,com.google.guava:listenablefuture:9999.0-empty-to-avoid-conflict-with-guava@jar,androidx.test.espresso:espresso-idling-resource:3.5.1@aar,com.squareup:javawriter:2.1.1@jar,com.google.firebase:firebase-annotations:16.2.0@jar,javax.inject:javax.inject:1@jar,androidx.resourceinspection:resourceinspection-annotation:1.0.1@jar,com.google.guava:failureaccess:1.0.1@jar,org.checkerframework:checker-qual:3.33.0@jar,com.google.errorprone:error_prone_annotations:2.18.0@jar,com.google.j2objc:j2objc-annotations:2.8@jar,com.google.code.gson:gson:2.8.5@jar,com.github.bumptech.glide:disklrucache:4.16.0@jar,com.github.bumptech.glide:annotations:4.16.0@jar,androidx.exifinterface:exifinterface:1.3.6@aar,com.google.firebase:protolite-well-known-types:18.0.0@aar,com.google.protobuf:protobuf-javalite:3.22.3@jar">
@@ -11,7 +11,7 @@
name="androidx.test.espresso:espresso-core:3.5.1@aar"
simpleName="androidx.test.espresso:espresso-core"/>
+
@@ -61,18 +64,24 @@
+
-
+
+
@@ -137,10 +146,10 @@
name="org.jetbrains.kotlinx:kotlinx-coroutines-play-services:1.7.3@jar"
simpleName="org.jetbrains.kotlinx:kotlinx-coroutines-play-services"/>
+
@@ -355,6 +367,15 @@
+
+
+
diff --git a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-libraries.xml b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-libraries.xml
index ef658d2..640ce2b 100644
--- a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-libraries.xml
+++ b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/debug-artifact-libraries.xml
@@ -4,9 +4,9 @@
project=":app"/>
+
+
-
+
+
+
+
+
+
+ desugaredMethodsFiles="/Users/230405/.gradle/caches/9.4.1/transforms/7473c73b078130e603dd1d8e008ab0b2/transformed/D8BackportedDesugaredMethods.txt">
diff --git a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/module.xml b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/module.xml
index fc99fdd..46518b9 100644
--- a/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/module.xml
+++ b/app/build/intermediates/android_test_lint_model/debug/generateDebugAndroidTestLintModel/module.xml
@@ -4,7 +4,7 @@
name=":app"
type="APP"
maven="Cuida:app:unspecified"
- agpVersion="9.1.0"
+ agpVersion="9.2.0"
buildFolder="build"
bootClassPath="/Users/230405/Library/Android/sdk/platforms/android-35/android.jar:/Users/230405/Library/Android/sdk/build-tools/36.0.0/core-lambda-stubs.jar"
javaSourceLevel="1.8"
diff --git a/app/build/intermediates/android_test_lint_partial_results/debug/lintAnalyzeDebugAndroidTest/out/lint-partial.xml b/app/build/intermediates/android_test_lint_partial_results/debug/lintAnalyzeDebugAndroidTest/out/lint-partial.xml
index 1972b5b..cc2b795 100644
--- a/app/build/intermediates/android_test_lint_partial_results/debug/lintAnalyzeDebugAndroidTest/out/lint-partial.xml
+++ b/app/build/intermediates/android_test_lint_partial_results/debug/lintAnalyzeDebugAndroidTest/out/lint-partial.xml
@@ -1,5 +1,5 @@
-
+
diff --git a/app/build.gradle b/app/build.gradle
index a7cac09..662d199 100644
--- a/app/build.gradle
+++ b/app/build.gradle
@@ -72,10 +72,11 @@ dependencies {
// Firebase BoM
implementation platform('com.google.firebase:firebase-bom:32.7.2')
// Firebase Auth, Firestore and Storage
implementation 'com.google.firebase:firebase-auth'
implementation 'com.google.firebase:firebase-firestore'
implementation 'com.google.firebase:firebase-storage'
+ implementation 'com.google.firebase:firebase-database'
// Glide for image loading
implementation 'com.github.bumptech.glide:glide:4.16.0'
@@ -72,10 +72,11 @@ dependencies {
// Firebase BoM
implementation platform('com.google.firebase:firebase-bom:32.7.2')
- // Firebase Auth, Firestore and Storage
+ // Firebase Auth, Firestore, Storage and Realtime Database
implementation 'com.google.firebase:firebase-auth'
implementation 'com.google.firebase:firebase-firestore'